local SCREEN_WIDTH = 800
local SCREEN_HEIGHT = 600
local GROUND_HEIGHT = 300
local GRAVITY_ACCEL = 500

local player = {
    width = 10, height = 16,
    x = 400, y = 300, -- position
    vx = 0, vy = 0, -- velocity  
    ax = 0, ay = GRAVITY_ACCEL, -- acceleration
    runAcceleration = 1000,
    velocityDamping = 0.01,
    jumpVelocity = -300,
}

function love.update (dt)
    local ax = 0
    local d = player.velocityDamping ^ dt -- damping factor
    
    if love.keyboard.isDown('a') then ax = ax - player.runAcceleration end
    if love.keyboard.isDown('d') then ax = ax + player.runAcceleration end
    if love.keyboard.isDown('w') and player.y == GROUND_HEIGHT then
        player.vy = player.jumpVelocity
    end
    
    player.ax = ax
    player.x = (player.ax * dt ^ 2 / 2 + player.vx * dt * d + player.x)
        % SCREEN_WIDTH
    player.vx = (player.ax * dt + player.vx) * d
    
    player.y = player.ay * dt ^ 2 / 2 + player.vy * dt + player.y
    player.vy = player.ay * dt + player.vy
    
    player.y = math.min(player.y, GROUND_HEIGHT)

end

function love.keyreleased (key)
    if key == 'w' and player.vy < 0 then
        player.vy = player.vy / 2
    end
end

function love.draw ()
    love.graphics.setColor(0, 128, 64)
    love.graphics.rectangle('fill',
        0, GROUND_HEIGHT, SCREEN_WIDTH, SCREEN_HEIGHT)
        
    love.graphics.setColor(0, 64, 128)
    love.graphics.rectangle('fill',
        0, 0, SCREEN_WIDTH, GROUND_HEIGHT)
        
    love.graphics.setColor(255, 128, 64)
    love.graphics.rectangle('fill',
        player.x - player.width, player.y - player.height,
        player.width * 2, player.height * 2)
end

